Class: AdvancedBilling::CurrencyOveragePrices
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- AdvancedBilling::CurrencyOveragePrices
- Defined in:
- lib/advanced_billing/models/currency_overage_prices.rb
Overview
Extends a component price point with currency overage prices.
Instance Attribute Summary collapse
-
#archived_at ⇒ DateTime
The identifier for the pricing scheme.
-
#component_id ⇒ Integer
The identifier for the pricing scheme.
-
#created_at ⇒ DateTime
The identifier for the pricing scheme.
-
#currency_overage_prices ⇒ Array[ComponentCurrencyPrice]
Applicable only to prepaid usage components.
-
#currency_prices ⇒ Array[ComponentCurrencyPrice]
An array of currency pricing data is available when multiple currencies are defined for the site.
-
#default ⇒ TrueClass | FalseClass
Note: Refer to type attribute instead.
-
#expiration_interval ⇒ Integer
Applicable only to prepaid usage components where rollover_prepaid_remainder is true.
-
#expiration_interval_unit ⇒ ExpirationIntervalUnit
Applicable only to prepaid usage components where rollover_prepaid_remainder is true.
-
#handle ⇒ String
The identifier for the pricing scheme.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#interval ⇒ Integer
The numerical interval.
-
#interval_unit ⇒ IntervalUnit
A string representing the interval unit for this component price point, either month or day.
-
#name ⇒ String
Note: Refer to type attribute instead.
-
#overage_prices ⇒ Array[ComponentPrice]
Applicable only to prepaid usage components.
-
#overage_pricing_scheme ⇒ PricingScheme
Applicable only to prepaid usage components.
-
#prices ⇒ Array[ComponentPrice]
The identifier for the pricing scheme.
-
#pricing_scheme ⇒ PricingScheme
The identifier for the pricing scheme.
-
#renew_prepaid_allocation ⇒ TrueClass | FalseClass
Applicable only to prepaid usage components.
-
#rollover_prepaid_remainder ⇒ TrueClass | FalseClass
Applicable only to prepaid usage components.
-
#subscription_id ⇒ Integer
(only used for Custom Pricing - ie. when the price point’s type is ‘custom`) The id of the subscription that the custom price point is for.
-
#tax_included ⇒ TrueClass | FalseClass
(only used for Custom Pricing - ie. when the price point’s type is ‘custom`) The id of the subscription that the custom price point is for.
-
#type ⇒ PricePointType
Price point type.
-
#updated_at ⇒ DateTime
The identifier for the pricing scheme.
-
#use_site_exchange_rate ⇒ TrueClass | FalseClass
Whether to use the site level exchange rate or define your own prices for each currency if you have multiple currencies defined on the site.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, type: SKIP, default: SKIP, name: SKIP, pricing_scheme: SKIP, component_id: SKIP, handle: SKIP, archived_at: SKIP, created_at: SKIP, updated_at: SKIP, prices: SKIP, use_site_exchange_rate: SKIP, subscription_id: SKIP, tax_included: SKIP, interval: SKIP, interval_unit: SKIP, currency_prices: SKIP, overage_prices: SKIP, overage_pricing_scheme: SKIP, renew_prepaid_allocation: SKIP, rollover_prepaid_remainder: SKIP, expiration_interval: SKIP, expiration_interval_unit: SKIP, currency_overage_prices: SKIP, additional_properties: {}) ⇒ CurrencyOveragePrices
constructor
A new instance of CurrencyOveragePrices.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_archived_at ⇒ Object
- #to_custom_created_at ⇒ Object
- #to_custom_updated_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #get_additional_properties, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, type: SKIP, default: SKIP, name: SKIP, pricing_scheme: SKIP, component_id: SKIP, handle: SKIP, archived_at: SKIP, created_at: SKIP, updated_at: SKIP, prices: SKIP, use_site_exchange_rate: SKIP, subscription_id: SKIP, tax_included: SKIP, interval: SKIP, interval_unit: SKIP, currency_prices: SKIP, overage_prices: SKIP, overage_pricing_scheme: SKIP, renew_prepaid_allocation: SKIP, rollover_prepaid_remainder: SKIP, expiration_interval: SKIP, expiration_interval_unit: SKIP, currency_overage_prices: SKIP, additional_properties: {}) ⇒ CurrencyOveragePrices
Returns a new instance of CurrencyOveragePrices.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 224 def initialize(id: SKIP, type: SKIP, default: SKIP, name: SKIP, pricing_scheme: SKIP, component_id: SKIP, handle: SKIP, archived_at: SKIP, created_at: SKIP, updated_at: SKIP, prices: SKIP, use_site_exchange_rate: SKIP, subscription_id: SKIP, tax_included: SKIP, interval: SKIP, interval_unit: SKIP, currency_prices: SKIP, overage_prices: SKIP, overage_pricing_scheme: SKIP, renew_prepaid_allocation: SKIP, rollover_prepaid_remainder: SKIP, expiration_interval: SKIP, expiration_interval_unit: SKIP, currency_overage_prices: SKIP, additional_properties: {}) # Add additional model properties to the instance. additional_properties.each do |_name, _value| instance_variable_set("@#{_name}", _value) end @id = id unless id == SKIP @type = type unless type == SKIP @default = default unless default == SKIP @name = name unless name == SKIP @pricing_scheme = pricing_scheme unless pricing_scheme == SKIP @component_id = component_id unless component_id == SKIP @handle = handle unless handle == SKIP @archived_at = archived_at unless archived_at == SKIP @created_at = created_at unless created_at == SKIP @updated_at = updated_at unless updated_at == SKIP @prices = prices unless prices == SKIP @use_site_exchange_rate = use_site_exchange_rate unless use_site_exchange_rate == SKIP @subscription_id = subscription_id unless subscription_id == SKIP @tax_included = tax_included unless tax_included == SKIP @interval = interval unless interval == SKIP @interval_unit = interval_unit unless interval_unit == SKIP @currency_prices = currency_prices unless currency_prices == SKIP @overage_prices = overage_prices unless overage_prices == SKIP @overage_pricing_scheme = overage_pricing_scheme unless overage_pricing_scheme == SKIP @renew_prepaid_allocation = renew_prepaid_allocation unless renew_prepaid_allocation == SKIP unless rollover_prepaid_remainder == SKIP @rollover_prepaid_remainder = rollover_prepaid_remainder end @expiration_interval = expiration_interval unless expiration_interval == SKIP @expiration_interval_unit = expiration_interval_unit unless expiration_interval_unit == SKIP @currency_overage_prices = currency_overage_prices unless currency_overage_prices == SKIP end |
Instance Attribute Details
#archived_at ⇒ DateTime
The identifier for the pricing scheme. See [Product Components](help.chargify.com/products/product-components.html) for an overview of pricing schemes.
56 57 58 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 56 def archived_at @archived_at end |
#component_id ⇒ Integer
The identifier for the pricing scheme. See [Product Components](help.chargify.com/products/product-components.html) for an overview of pricing schemes.
44 45 46 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 44 def component_id @component_id end |
#created_at ⇒ DateTime
The identifier for the pricing scheme. See [Product Components](help.chargify.com/products/product-components.html) for an overview of pricing schemes.
62 63 64 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 62 def created_at @created_at end |
#currency_overage_prices ⇒ Array[ComponentCurrencyPrice]
Applicable only to prepaid usage components. An array of currency pricing data for overage prices.
150 151 152 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 150 def currency_overage_prices @currency_overage_prices end |
#currency_prices ⇒ Array[ComponentCurrencyPrice]
An array of currency pricing data is available when multiple currencies are defined for the site. It varies based on the use_site_exchange_rate setting for the price point. This parameter is present only in the response of read endpoints, after including the appropriate query parameter. The clone endpoint always returns currency prices if they are present.
112 113 114 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 112 def currency_prices @currency_prices end |
#default ⇒ TrueClass | FalseClass
Note: Refer to type attribute instead
28 29 30 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 28 def default @default end |
#expiration_interval ⇒ Integer
Applicable only to prepaid usage components where rollover_prepaid_remainder is true. The number of ‘expiration_interval_unit`s after which rollover amounts should expire.
139 140 141 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 139 def expiration_interval @expiration_interval end |
#expiration_interval_unit ⇒ ExpirationIntervalUnit
Applicable only to prepaid usage components where rollover_prepaid_remainder is true. A string representing the expiration interval unit for this component, either month or day.
145 146 147 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 145 def expiration_interval_unit @expiration_interval_unit end |
#handle ⇒ String
The identifier for the pricing scheme. See [Product Components](help.chargify.com/products/product-components.html) for an overview of pricing schemes.
50 51 52 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 50 def handle @handle end |
#id ⇒ Integer
TODO: Write general description for this method
15 16 17 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 15 def id @id end |
#interval ⇒ Integer
The numerical interval. i.e. an interval of ‘30’ coupled with an interval_unit of day would mean this component price point would renew every 30 days. This property is only available for sites with Multifrequency enabled.
97 98 99 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 97 def interval @interval end |
#interval_unit ⇒ IntervalUnit
A string representing the interval unit for this component price point, either month or day. This property is only available for sites with Multifrequency enabled.
103 104 105 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 103 def interval_unit @interval_unit end |
#name ⇒ String
Note: Refer to type attribute instead
32 33 34 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 32 def name @name end |
#overage_prices ⇒ Array[ComponentPrice]
Applicable only to prepaid usage components. An array of overage price brackets.
117 118 119 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 117 def overage_prices @overage_prices end |
#overage_pricing_scheme ⇒ PricingScheme
Applicable only to prepaid usage components. Pricing scheme for overage pricing.
122 123 124 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 122 def overage_pricing_scheme @overage_pricing_scheme end |
#prices ⇒ Array[ComponentPrice]
The identifier for the pricing scheme. See [Product Components](help.chargify.com/products/product-components.html) for an overview of pricing schemes.
74 75 76 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 74 def prices @prices end |
#pricing_scheme ⇒ PricingScheme
The identifier for the pricing scheme. See [Product Components](help.chargify.com/products/product-components.html) for an overview of pricing schemes.
38 39 40 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 38 def pricing_scheme @pricing_scheme end |
#renew_prepaid_allocation ⇒ TrueClass | FalseClass
Applicable only to prepaid usage components. Boolean which controls whether or not the allocated quantity should be renewed at the beginning of each period.
128 129 130 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 128 def renew_prepaid_allocation @renew_prepaid_allocation end |
#rollover_prepaid_remainder ⇒ TrueClass | FalseClass
Applicable only to prepaid usage components. Boolean which controls whether or not remaining units should be rolled over to the next period.
133 134 135 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 133 def rollover_prepaid_remainder @rollover_prepaid_remainder end |
#subscription_id ⇒ Integer
(only used for Custom Pricing - ie. when the price point’s type is ‘custom`) The id of the subscription that the custom price point is for.
85 86 87 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 85 def subscription_id @subscription_id end |
#tax_included ⇒ TrueClass | FalseClass
(only used for Custom Pricing - ie. when the price point’s type is ‘custom`) The id of the subscription that the custom price point is for.
90 91 92 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 90 def tax_included @tax_included end |
#type ⇒ PricePointType
Price point type. We expose the following types:
-
default: a price point that is marked as a default price for a
certain product.
-
custom: a custom price point.
-
catalog: a price point that is not marked as a default price
for a certain product and is not a custom one.
24 25 26 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 24 def type @type end |
#updated_at ⇒ DateTime
The identifier for the pricing scheme. See [Product Components](help.chargify.com/products/product-components.html) for an overview of pricing schemes.
68 69 70 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 68 def updated_at @updated_at end |
#use_site_exchange_rate ⇒ TrueClass | FalseClass
Whether to use the site level exchange rate or define your own prices for each currency if you have multiple currencies defined on the site. Defaults to true during creation.
80 81 82 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 80 def use_site_exchange_rate @use_site_exchange_rate end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 270 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP default = hash.key?('default') ? hash['default'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP pricing_scheme = hash.key?('pricing_scheme') ? hash['pricing_scheme'] : SKIP component_id = hash.key?('component_id') ? hash['component_id'] : SKIP handle = hash.key?('handle') ? hash['handle'] : SKIP archived_at = if hash.key?('archived_at') (DateTimeHelper.from_rfc3339(hash['archived_at']) if hash['archived_at']) else SKIP end created_at = if hash.key?('created_at') (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at']) else SKIP end updated_at = if hash.key?('updated_at') (DateTimeHelper.from_rfc3339(hash['updated_at']) if hash['updated_at']) else SKIP end # Parameter is an array, so we need to iterate through it prices = nil unless hash['prices'].nil? prices = [] hash['prices'].each do |structure| prices << (ComponentPrice.from_hash(structure) if structure) end end prices = SKIP unless hash.key?('prices') use_site_exchange_rate = hash.key?('use_site_exchange_rate') ? hash['use_site_exchange_rate'] : SKIP subscription_id = hash.key?('subscription_id') ? hash['subscription_id'] : SKIP tax_included = hash.key?('tax_included') ? hash['tax_included'] : SKIP interval = hash.key?('interval') ? hash['interval'] : SKIP interval_unit = hash.key?('interval_unit') ? hash['interval_unit'] : SKIP # Parameter is an array, so we need to iterate through it currency_prices = nil unless hash['currency_prices'].nil? currency_prices = [] hash['currency_prices'].each do |structure| currency_prices << (ComponentCurrencyPrice.from_hash(structure) if structure) end end currency_prices = SKIP unless hash.key?('currency_prices') # Parameter is an array, so we need to iterate through it overage_prices = nil unless hash['overage_prices'].nil? overage_prices = [] hash['overage_prices'].each do |structure| overage_prices << (ComponentPrice.from_hash(structure) if structure) end end overage_prices = SKIP unless hash.key?('overage_prices') overage_pricing_scheme = hash.key?('overage_pricing_scheme') ? hash['overage_pricing_scheme'] : SKIP renew_prepaid_allocation = hash.key?('renew_prepaid_allocation') ? hash['renew_prepaid_allocation'] : SKIP rollover_prepaid_remainder = hash.key?('rollover_prepaid_remainder') ? hash['rollover_prepaid_remainder'] : SKIP expiration_interval = hash.key?('expiration_interval') ? hash['expiration_interval'] : SKIP expiration_interval_unit = hash.key?('expiration_interval_unit') ? hash['expiration_interval_unit'] : SKIP # Parameter is an array, so we need to iterate through it currency_overage_prices = nil unless hash['currency_overage_prices'].nil? currency_overage_prices = [] hash['currency_overage_prices'].each do |structure| currency_overage_prices << (ComponentCurrencyPrice.from_hash(structure) if structure) end end currency_overage_prices = SKIP unless hash.key?('currency_overage_prices') # Clean out expected properties from Hash. additional_properties = hash.reject { |k, _| names.value?(k) } # Create object from extracted values. CurrencyOveragePrices.new(id: id, type: type, default: default, name: name, pricing_scheme: pricing_scheme, component_id: component_id, handle: handle, archived_at: archived_at, created_at: created_at, updated_at: updated_at, prices: prices, use_site_exchange_rate: use_site_exchange_rate, subscription_id: subscription_id, tax_included: tax_included, interval: interval, interval_unit: interval_unit, currency_prices: currency_prices, overage_prices: overage_prices, overage_pricing_scheme: overage_pricing_scheme, renew_prepaid_allocation: renew_prepaid_allocation, rollover_prepaid_remainder: rollover_prepaid_remainder, expiration_interval: expiration_interval, expiration_interval_unit: expiration_interval_unit, currency_overage_prices: currency_overage_prices, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 153 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['type'] = 'type' @_hash['default'] = 'default' @_hash['name'] = 'name' @_hash['pricing_scheme'] = 'pricing_scheme' @_hash['component_id'] = 'component_id' @_hash['handle'] = 'handle' @_hash['archived_at'] = 'archived_at' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['prices'] = 'prices' @_hash['use_site_exchange_rate'] = 'use_site_exchange_rate' @_hash['subscription_id'] = 'subscription_id' @_hash['tax_included'] = 'tax_included' @_hash['interval'] = 'interval' @_hash['interval_unit'] = 'interval_unit' @_hash['currency_prices'] = 'currency_prices' @_hash['overage_prices'] = 'overage_prices' @_hash['overage_pricing_scheme'] = 'overage_pricing_scheme' @_hash['renew_prepaid_allocation'] = 'renew_prepaid_allocation' @_hash['rollover_prepaid_remainder'] = 'rollover_prepaid_remainder' @_hash['expiration_interval'] = 'expiration_interval' @_hash['expiration_interval_unit'] = 'expiration_interval_unit' @_hash['currency_overage_prices'] = 'currency_overage_prices' @_hash end |
.nullables ⇒ Object
An array for nullable fields
213 214 215 216 217 218 219 220 221 222 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 213 def self.nullables %w[ handle archived_at interval interval_unit expiration_interval expiration_interval_unit ] end |
.optionals ⇒ Object
An array for optional fields
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 183 def self.optionals %w[ id type default name pricing_scheme component_id handle archived_at created_at updated_at prices use_site_exchange_rate subscription_id tax_included interval interval_unit currency_prices overage_prices overage_pricing_scheme renew_prepaid_allocation rollover_prepaid_remainder expiration_interval expiration_interval_unit currency_overage_prices ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 415 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, type: #{@type.inspect}, default: #{@default.inspect},"\ " name: #{@name.inspect}, pricing_scheme: #{@pricing_scheme.inspect}, component_id:"\ " #{@component_id.inspect}, handle: #{@handle.inspect}, archived_at:"\ " #{@archived_at.inspect}, created_at: #{@created_at.inspect}, updated_at:"\ " #{@updated_at.inspect}, prices: #{@prices.inspect}, use_site_exchange_rate:"\ " #{@use_site_exchange_rate.inspect}, subscription_id: #{@subscription_id.inspect},"\ " tax_included: #{@tax_included.inspect}, interval: #{@interval.inspect}, interval_unit:"\ " #{@interval_unit.inspect}, currency_prices: #{@currency_prices.inspect}, overage_prices:"\ " #{@overage_prices.inspect}, overage_pricing_scheme: #{@overage_pricing_scheme.inspect},"\ " renew_prepaid_allocation: #{@renew_prepaid_allocation.inspect},"\ " rollover_prepaid_remainder: #{@rollover_prepaid_remainder.inspect}, expiration_interval:"\ " #{@expiration_interval.inspect}, expiration_interval_unit:"\ " #{@expiration_interval_unit.inspect}, currency_overage_prices:"\ " #{@currency_overage_prices.inspect}, additional_properties: #{get_additional_properties}>" end |
#to_custom_archived_at ⇒ Object
386 387 388 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 386 def to_custom_archived_at DateTimeHelper.to_rfc3339(archived_at) end |
#to_custom_created_at ⇒ Object
390 391 392 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 390 def to_custom_created_at DateTimeHelper.to_rfc3339(created_at) end |
#to_custom_updated_at ⇒ Object
394 395 396 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 394 def to_custom_updated_at DateTimeHelper.to_rfc3339(updated_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/advanced_billing/models/currency_overage_prices.rb', line 399 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, type: #{@type}, default: #{@default}, name: #{@name},"\ " pricing_scheme: #{@pricing_scheme}, component_id: #{@component_id}, handle: #{@handle},"\ " archived_at: #{@archived_at}, created_at: #{@created_at}, updated_at: #{@updated_at},"\ " prices: #{@prices}, use_site_exchange_rate: #{@use_site_exchange_rate}, subscription_id:"\ " #{@subscription_id}, tax_included: #{@tax_included}, interval: #{@interval},"\ " interval_unit: #{@interval_unit}, currency_prices: #{@currency_prices}, overage_prices:"\ " #{@overage_prices}, overage_pricing_scheme: #{@overage_pricing_scheme},"\ " renew_prepaid_allocation: #{@renew_prepaid_allocation}, rollover_prepaid_remainder:"\ " #{@rollover_prepaid_remainder}, expiration_interval: #{@expiration_interval},"\ " expiration_interval_unit: #{@expiration_interval_unit}, currency_overage_prices:"\ " #{@currency_overage_prices}, additional_properties: #{get_additional_properties}>" end |