Class: AdvancedBilling::EBBComponent
- Defined in:
- lib/advanced_billing/models/ebb_component.rb
Overview
EBBComponent Model.
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the component that will be displayed to the user on the hosted signup page.
-
#event_based_billing_metric_id ⇒ Integer
The ID of an event based billing metric that will be attached to this component.
-
#handle ⇒ String
A unique identifier for your use that can be used to retrieve this component in subsequent requests.
-
#hide_date_range_on_invoice ⇒ TrueClass | FalseClass
(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.
-
#interval ⇒ Integer
The numerical interval.
-
#interval_unit ⇒ IntervalUnit
A string representing the interval unit for this component's default price point, either month or day.
-
#name ⇒ String
A name for this component that is suitable for showing customers and displaying on billing statements, i.e., "Minutes".
-
#price_points ⇒ Array[ComponentPricePointItem]
(Not required for ‘per_unit’ pricing schemes) One or more price brackets.
-
#prices ⇒ Array[Price]
(Not required for ‘per_unit’ pricing schemes) One or more price brackets.
-
#pricing_scheme ⇒ PricingScheme
The identifier for the pricing scheme.
-
#tax_code ⇒ String
A string representing the tax code related to the component type.
-
#taxable ⇒ TrueClass | FalseClass
Boolean flag describing whether a component is taxable or not.
-
#unit_name ⇒ String
“The name of the unit of measurement for the component.
-
#unit_price ⇒ Object
The amount the customer will be charged per unit when the pricing scheme is “per_unit”.
-
#unspsc_code ⇒ String
(Optional) Custom UNSPSC commodity code for Level 3/CEDP payment data.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(name:, unit_name:, pricing_scheme:, event_based_billing_metric_id:, description: SKIP, handle: SKIP, taxable: SKIP, prices: SKIP, price_points: SKIP, unit_price: SKIP, tax_code: SKIP, hide_date_range_on_invoice: SKIP, interval: SKIP, interval_unit: SKIP, unspsc_code: SKIP, additional_properties: {}) ⇒ EBBComponent
constructor
A new instance of EBBComponent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #get_additional_properties, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, unit_name:, pricing_scheme:, event_based_billing_metric_id:, description: SKIP, handle: SKIP, taxable: SKIP, prices: SKIP, price_points: SKIP, unit_price: SKIP, tax_code: SKIP, hide_date_range_on_invoice: SKIP, interval: SKIP, interval_unit: SKIP, unspsc_code: SKIP, additional_properties: {}) ⇒ EBBComponent
Returns a new instance of EBBComponent.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 151 def initialize(name:, unit_name:, pricing_scheme:, event_based_billing_metric_id:, description: SKIP, handle: SKIP, taxable: SKIP, prices: SKIP, price_points: SKIP, unit_price: SKIP, tax_code: SKIP, hide_date_range_on_invoice: SKIP, interval: SKIP, interval_unit: SKIP, unspsc_code: SKIP, additional_properties: {}) # Add additional model properties to the instance. additional_properties.each do |_name, _value| instance_variable_set("@#{_name}", _value) end @name = name @unit_name = unit_name @description = description unless description == SKIP @handle = handle unless handle == SKIP @taxable = taxable unless taxable == SKIP @pricing_scheme = pricing_scheme @prices = prices unless prices == SKIP @price_points = price_points unless price_points == SKIP @unit_price = unit_price unless unit_price == SKIP @tax_code = tax_code unless tax_code == SKIP unless hide_date_range_on_invoice == SKIP @hide_date_range_on_invoice = hide_date_range_on_invoice end @event_based_billing_metric_id = event_based_billing_metric_id @interval = interval unless interval == SKIP @interval_unit = interval_unit unless interval_unit == SKIP @unspsc_code = unspsc_code unless unspsc_code == SKIP end |
Instance Attribute Details
#description ⇒ String
A description for the component that will be displayed to the user on the hosted signup page.
27 28 29 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 27 def description @description end |
#event_based_billing_metric_id ⇒ Integer
The ID of an event based billing metric that will be attached to this component.
83 84 85 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 83 def event_based_billing_metric_id @event_based_billing_metric_id end |
#handle ⇒ String
A unique identifier for your use that can be used to retrieve this component in subsequent requests. Must start with a letter or number and may only contain lowercase letters, numbers, or the characters '.', ':', '-', or '_'.
34 35 36 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 34 def handle @handle end |
#hide_date_range_on_invoice ⇒ TrueClass | FalseClass
(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.
78 79 80 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 78 def hide_date_range_on_invoice @hide_date_range_on_invoice end |
#interval ⇒ Integer
The numerical interval. i.e., an interval of ‘30’ coupled with an interval_unit of day would mean this component's default price point would renew every 30 days. This property is only available for sites with Multifrequency enabled.
90 91 92 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 90 def interval @interval end |
#interval_unit ⇒ IntervalUnit
A string representing the interval unit for this component's default price point, either month or day. This property is only available for sites with Multifrequency enabled.
96 97 98 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 96 def interval_unit @interval_unit end |
#name ⇒ String
A name for this component that is suitable for showing customers and displaying on billing statements, i.e., "Minutes".
15 16 17 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 15 def name @name end |
#price_points ⇒ Array[ComponentPricePointItem]
(Not required for ‘per_unit’ pricing schemes) One or more price brackets. See [Price Bracket Rules](https://maxio.zendesk.com/hc/en-us/articles/24261149166733-Componen t-Pricing-Schemes#price-bracket-rules) for an overview of how price brackets work for different pricing schemes.
60 61 62 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 60 def price_points @price_points end |
#prices ⇒ Array[Price]
(Not required for ‘per_unit’ pricing schemes) One or more price brackets. See [Price Bracket Rules](https://maxio.zendesk.com/hc/en-us/articles/24261149166733-Componen t-Pricing-Schemes#price-bracket-rules) for an overview of how price brackets work for different pricing schemes.
52 53 54 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 52 def prices @prices end |
#pricing_scheme ⇒ PricingScheme
The identifier for the pricing scheme. See Product Components for an overview of pricing schemes.
44 45 46 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 44 def pricing_scheme @pricing_scheme end |
#tax_code ⇒ String
A string representing the tax code related to the component type. This is especially important when using AvaTax to tax based on locale. This attribute has a max length of 25 characters.
72 73 74 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 72 def tax_code @tax_code end |
#taxable ⇒ TrueClass | FalseClass
Boolean flag describing whether a component is taxable or not.
38 39 40 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 38 def taxable @taxable end |
#unit_name ⇒ String
“The name of the unit of measurement for the component. It should be singular since it will be automatically pluralized when necessary. i.e., “message”, which may then be shown as “5 messages” on a subscription’s component line-item”
22 23 24 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 22 def unit_name @unit_name end |
#unit_price ⇒ Object
The amount the customer will be charged per unit when the pricing scheme is “per_unit”. The price can contain up to 8 decimal places. i.e., 1.00 or 0.0012 or 0.00000065
66 67 68 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 66 def unit_price @unit_price end |
#unspsc_code ⇒ String
(Optional) Custom UNSPSC commodity code for Level 3/CEDP payment data. When set, this value is sent as the commodity code on invoice line items for this component instead of the default derived from item_category.
102 103 104 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 102 def unspsc_code @unspsc_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 184 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil unit_name = hash.key?('unit_name') ? hash['unit_name'] : nil pricing_scheme = hash.key?('pricing_scheme') ? hash['pricing_scheme'] : nil event_based_billing_metric_id = hash.key?('event_based_billing_metric_id') ? hash['event_based_billing_metric_id'] : nil description = hash.key?('description') ? hash['description'] : SKIP handle = hash.key?('handle') ? hash['handle'] : SKIP taxable = hash.key?('taxable') ? hash['taxable'] : SKIP # Parameter is an array, so we need to iterate through it prices = nil unless hash['prices'].nil? prices = [] hash['prices'].each do |structure| prices << (Price.from_hash(structure) if structure) end end prices = SKIP unless hash.key?('prices') # Parameter is an array, so we need to iterate through it price_points = nil unless hash['price_points'].nil? price_points = [] hash['price_points'].each do |structure| price_points << (ComponentPricePointItem.from_hash(structure) if structure) end end price_points = SKIP unless hash.key?('price_points') unit_price = hash.key?('unit_price') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:EBBComponentUnitPrice), hash['unit_price'] ) : SKIP tax_code = hash.key?('tax_code') ? hash['tax_code'] : SKIP hide_date_range_on_invoice = hash.key?('hide_date_range_on_invoice') ? hash['hide_date_range_on_invoice'] : SKIP interval = hash.key?('interval') ? hash['interval'] : SKIP interval_unit = hash.key?('interval_unit') ? hash['interval_unit'] : SKIP unspsc_code = hash.key?('unspsc_code') ? hash['unspsc_code'] : SKIP # Clean out expected properties from Hash. additional_properties = hash.reject { |k, _| names.value?(k) } # Create object from extracted values. EBBComponent.new(name: name, unit_name: unit_name, pricing_scheme: pricing_scheme, event_based_billing_metric_id: event_based_billing_metric_id, description: description, handle: handle, taxable: taxable, prices: prices, price_points: price_points, unit_price: unit_price, tax_code: tax_code, hide_date_range_on_invoice: hide_date_range_on_invoice, interval: interval, interval_unit: interval_unit, unspsc_code: unspsc_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 105 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['unit_name'] = 'unit_name' @_hash['description'] = 'description' @_hash['handle'] = 'handle' @_hash['taxable'] = 'taxable' @_hash['pricing_scheme'] = 'pricing_scheme' @_hash['prices'] = 'prices' @_hash['price_points'] = 'price_points' @_hash['unit_price'] = 'unit_price' @_hash['tax_code'] = 'tax_code' @_hash['hide_date_range_on_invoice'] = 'hide_date_range_on_invoice' @_hash['event_based_billing_metric_id'] = 'event_based_billing_metric_id' @_hash['interval'] = 'interval' @_hash['interval_unit'] = 'interval_unit' @_hash['unspsc_code'] = 'unspsc_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
144 145 146 147 148 149 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 144 def self.nullables %w[ interval_unit unspsc_code ] end |
.optionals ⇒ Object
An array for optional fields
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 127 def self.optionals %w[ description handle taxable prices price_points unit_price tax_code hide_date_range_on_invoice interval interval_unit unspsc_code ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 251 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.unit_name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.pricing_scheme, ->(val) { PricingScheme.validate(val) }) and APIHelper.valid_type?(value.event_based_billing_metric_id, ->(val) { val.instance_of? Integer }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['unit_name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['pricing_scheme'], ->(val) { PricingScheme.validate(val) }) and APIHelper.valid_type?(value['event_based_billing_metric_id'], ->(val) { val.instance_of? Integer }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 292 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, unit_name: #{@unit_name.inspect}, description:"\ " #{@description.inspect}, handle: #{@handle.inspect}, taxable: #{@taxable.inspect},"\ " pricing_scheme: #{@pricing_scheme.inspect}, prices: #{@prices.inspect}, price_points:"\ " #{@price_points.inspect}, unit_price: #{@unit_price.inspect}, tax_code:"\ " #{@tax_code.inspect}, hide_date_range_on_invoice: #{@hide_date_range_on_invoice.inspect},"\ " event_based_billing_metric_id: #{@event_based_billing_metric_id.inspect}, interval:"\ " #{@interval.inspect}, interval_unit: #{@interval_unit.inspect}, unspsc_code:"\ " #{@unspsc_code.inspect}, additional_properties: #{get_additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
280 281 282 283 284 285 286 287 288 289 |
# File 'lib/advanced_billing/models/ebb_component.rb', line 280 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, unit_name: #{@unit_name}, description: #{@description},"\ " handle: #{@handle}, taxable: #{@taxable}, pricing_scheme: #{@pricing_scheme}, prices:"\ " #{@prices}, price_points: #{@price_points}, unit_price: #{@unit_price}, tax_code:"\ " #{@tax_code}, hide_date_range_on_invoice: #{@hide_date_range_on_invoice},"\ " event_based_billing_metric_id: #{@event_based_billing_metric_id}, interval: #{@interval},"\ " interval_unit: #{@interval_unit}, unspsc_code: #{@unspsc_code}, additional_properties:"\ " #{get_additional_properties}>" end |