Class: AdvancedBilling::MeteredComponent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/advanced_billing/models/metered_component.rb

Overview

MeteredComponent Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #get_additional_properties, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, unit_name:, pricing_scheme:, description: SKIP, handle: SKIP, taxable: SKIP, prices: SKIP, price_points: SKIP, unit_price: SKIP, tax_code: SKIP, hide_date_range_on_invoice: SKIP, display_on_hosted_page: SKIP, allow_fractional_quantities: SKIP, public_signup_page_ids: SKIP, interval: SKIP, interval_unit: SKIP, unspsc_code: SKIP, additional_properties: {}) ⇒ MeteredComponent

Returns a new instance of MeteredComponent.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/advanced_billing/models/metered_component.rb', line 170

def initialize(name:, unit_name:, pricing_scheme:, description: SKIP,
               handle: SKIP, taxable: SKIP, prices: SKIP,
               price_points: SKIP, unit_price: SKIP, tax_code: SKIP,
               hide_date_range_on_invoice: SKIP,
               display_on_hosted_page: SKIP,
               allow_fractional_quantities: SKIP,
               public_signup_page_ids: SKIP, interval: SKIP,
               interval_unit: SKIP, unspsc_code: SKIP,
               additional_properties: {})
  # Add additional model properties to the instance.
  additional_properties.each do |_name, _value|
    instance_variable_set("@#{_name}", _value)
  end

  @name = name
  @unit_name = unit_name
  @description = description unless description == SKIP
  @handle = handle unless handle == SKIP
  @taxable = taxable unless taxable == SKIP
  @pricing_scheme = pricing_scheme
  @prices = prices unless prices == SKIP
  @price_points = price_points unless price_points == SKIP
  @unit_price = unit_price unless unit_price == SKIP
  @tax_code = tax_code unless tax_code == SKIP
  unless hide_date_range_on_invoice == SKIP
    @hide_date_range_on_invoice =
      hide_date_range_on_invoice
  end
  @display_on_hosted_page = display_on_hosted_page unless display_on_hosted_page == SKIP
  unless allow_fractional_quantities == SKIP
    @allow_fractional_quantities =
      allow_fractional_quantities
  end
  @public_signup_page_ids =  unless  == SKIP
  @interval = interval unless interval == SKIP
  @interval_unit = interval_unit unless interval_unit == SKIP
  @unspsc_code = unspsc_code unless unspsc_code == SKIP
end

Instance Attribute Details

#allow_fractional_quantitiesTrueClass | FalseClass

(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.

Returns:

  • (TrueClass | FalseClass)


92
93
94
# File 'lib/advanced_billing/models/metered_component.rb', line 92

def allow_fractional_quantities
  @allow_fractional_quantities
end

#descriptionString

A description for the component that will be displayed to the user on the hosted signup page.

Returns:

  • (String)


27
28
29
# File 'lib/advanced_billing/models/metered_component.rb', line 27

def description
  @description
end

#display_on_hosted_pageTrueClass | FalseClass

(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.

Returns:

  • (TrueClass | FalseClass)


86
87
88
# File 'lib/advanced_billing/models/metered_component.rb', line 86

def display_on_hosted_page
  @display_on_hosted_page
end

#handleString

A unique identifier for your use that can be used to retrieve this component in subsequent requests. Must start with a letter or number and may only contain lowercase letters, numbers, or the characters '.', ':', '-', or '_'.

Returns:

  • (String)


34
35
36
# File 'lib/advanced_billing/models/metered_component.rb', line 34

def handle
  @handle
end

#hide_date_range_on_invoiceTrueClass | FalseClass

(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.

Returns:

  • (TrueClass | FalseClass)


80
81
82
# File 'lib/advanced_billing/models/metered_component.rb', line 80

def hide_date_range_on_invoice
  @hide_date_range_on_invoice
end

#intervalInteger

The numerical interval. e.g., an interval of ‘30’ coupled with an interval_unit of day would mean this component's default price point would renew every 30 days. This property is only available for sites with Multifrequency enabled.

Returns:

  • (Integer)


105
106
107
# File 'lib/advanced_billing/models/metered_component.rb', line 105

def interval
  @interval
end

#interval_unitIntervalUnit

A string representing the interval unit for this component's default price point, either month or day. This property is only available for sites with Multifrequency enabled.

Returns:



111
112
113
# File 'lib/advanced_billing/models/metered_component.rb', line 111

def interval_unit
  @interval_unit
end

#nameString

A name for this component that is suitable for showing customers and displaying on billing statements, e.g., "Minutes".

Returns:

  • (String)


15
16
17
# File 'lib/advanced_billing/models/metered_component.rb', line 15

def name
  @name
end

#price_pointsArray[ComponentPricePointItem]

(Not required for ‘per_unit’ pricing schemes) One or more price brackets. See [Price Bracket Rules](https://maxio.zendesk.com/hc/en-us/articles/24261149166733-Componen t-Pricing-Schemes#price-bracket-rules) for an overview of how price brackets work for different pricing schemes.

Returns:



60
61
62
# File 'lib/advanced_billing/models/metered_component.rb', line 60

def price_points
  @price_points
end

#pricesArray[Price]

(Not required for ‘per_unit’ pricing schemes) One or more price brackets. See [Price Bracket Rules](https://maxio.zendesk.com/hc/en-us/articles/24261149166733-Componen t-Pricing-Schemes#price-bracket-rules) for an overview of how price brackets work for different pricing schemes.

Returns:



52
53
54
# File 'lib/advanced_billing/models/metered_component.rb', line 52

def prices
  @prices
end

#pricing_schemePricingScheme

The identifier for the pricing scheme. See Product Components for an overview of pricing schemes.

Returns:



44
45
46
# File 'lib/advanced_billing/models/metered_component.rb', line 44

def pricing_scheme
  @pricing_scheme
end

#public_signup_page_idsArray[Integer]

(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.

Returns:

  • (Array[Integer])


98
99
100
# File 'lib/advanced_billing/models/metered_component.rb', line 98

def 
  @public_signup_page_ids
end

#tax_codeString

A string representing the tax code related to the component type. This is especially important when using AvaTax to tax based on locale. This attribute has a max length of 25 characters.

Returns:

  • (String)


74
75
76
# File 'lib/advanced_billing/models/metered_component.rb', line 74

def tax_code
  @tax_code
end

#taxableTrueClass | FalseClass

Boolean flag describing whether a component is taxable or not.

Returns:

  • (TrueClass | FalseClass)


38
39
40
# File 'lib/advanced_billing/models/metered_component.rb', line 38

def taxable
  @taxable
end

#unit_nameString

The name of the unit of measurement for the component. It should be singular since it will be automatically pluralized when necessary. e.g., “message”, which may then be shown as “5 messages” on a subscription’s component line-item

Returns:

  • (String)


22
23
24
# File 'lib/advanced_billing/models/metered_component.rb', line 22

def unit_name
  @unit_name
end

#unit_priceObject

The amount the customer will be charged per unit when the pricing scheme is “per_unit”. For On/Off Components, this is the amount that the customer will be charged when they turn the component on for the subscription. The price can contain up to 8 decimal places. e.g., 1.00 or 0.0012 or 0.00000065

Returns:

  • (Object)


68
69
70
# File 'lib/advanced_billing/models/metered_component.rb', line 68

def unit_price
  @unit_price
end

#unspsc_codeString

(Optional) Custom UNSPSC commodity code for Level 3/CEDP payment data. When set, this value is sent as the commodity code on invoice line items for this component instead of the default derived from item_category.

Returns:

  • (String)


117
118
119
# File 'lib/advanced_billing/models/metered_component.rb', line 117

def unspsc_code
  @unspsc_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/advanced_billing/models/metered_component.rb', line 210

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  unit_name = hash.key?('unit_name') ? hash['unit_name'] : nil
  pricing_scheme =
    hash.key?('pricing_scheme') ? hash['pricing_scheme'] : nil
  description = hash.key?('description') ? hash['description'] : SKIP
  handle = hash.key?('handle') ? hash['handle'] : SKIP
  taxable = hash.key?('taxable') ? hash['taxable'] : SKIP
  # Parameter is an array, so we need to iterate through it
  prices = nil
  unless hash['prices'].nil?
    prices = []
    hash['prices'].each do |structure|
      prices << (Price.from_hash(structure) if structure)
    end
  end

  prices = SKIP unless hash.key?('prices')
  # Parameter is an array, so we need to iterate through it
  price_points = nil
  unless hash['price_points'].nil?
    price_points = []
    hash['price_points'].each do |structure|
      price_points << (ComponentPricePointItem.from_hash(structure) if structure)
    end
  end

  price_points = SKIP unless hash.key?('price_points')
  unit_price = hash.key?('unit_price') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:MeteredComponentUnitPrice), hash['unit_price']
  ) : SKIP
  tax_code = hash.key?('tax_code') ? hash['tax_code'] : SKIP
  hide_date_range_on_invoice =
    hash.key?('hide_date_range_on_invoice') ? hash['hide_date_range_on_invoice'] : SKIP
  display_on_hosted_page =
    hash.key?('display_on_hosted_page') ? hash['display_on_hosted_page'] : SKIP
  allow_fractional_quantities =
    hash.key?('allow_fractional_quantities') ? hash['allow_fractional_quantities'] : SKIP
   =
    hash.key?('public_signup_page_ids') ? hash['public_signup_page_ids'] : SKIP
  interval = hash.key?('interval') ? hash['interval'] : SKIP
  interval_unit = hash.key?('interval_unit') ? hash['interval_unit'] : SKIP
  unspsc_code = hash.key?('unspsc_code') ? hash['unspsc_code'] : SKIP

  # Clean out expected properties from Hash.
  additional_properties = hash.reject { |k, _| names.value?(k) }

  # Create object from extracted values.
  MeteredComponent.new(name: name,
                       unit_name: unit_name,
                       pricing_scheme: pricing_scheme,
                       description: description,
                       handle: handle,
                       taxable: taxable,
                       prices: prices,
                       price_points: price_points,
                       unit_price: unit_price,
                       tax_code: tax_code,
                       hide_date_range_on_invoice: hide_date_range_on_invoice,
                       display_on_hosted_page: display_on_hosted_page,
                       allow_fractional_quantities: allow_fractional_quantities,
                       public_signup_page_ids: ,
                       interval: interval,
                       interval_unit: interval_unit,
                       unspsc_code: unspsc_code,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/advanced_billing/models/metered_component.rb', line 120

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['unit_name'] = 'unit_name'
  @_hash['description'] = 'description'
  @_hash['handle'] = 'handle'
  @_hash['taxable'] = 'taxable'
  @_hash['pricing_scheme'] = 'pricing_scheme'
  @_hash['prices'] = 'prices'
  @_hash['price_points'] = 'price_points'
  @_hash['unit_price'] = 'unit_price'
  @_hash['tax_code'] = 'tax_code'
  @_hash['hide_date_range_on_invoice'] = 'hide_date_range_on_invoice'
  @_hash['display_on_hosted_page'] = 'display_on_hosted_page'
  @_hash['allow_fractional_quantities'] = 'allow_fractional_quantities'
  @_hash['public_signup_page_ids'] = 'public_signup_page_ids'
  @_hash['interval'] = 'interval'
  @_hash['interval_unit'] = 'interval_unit'
  @_hash['unspsc_code'] = 'unspsc_code'
  @_hash
end

.nullablesObject

An array for nullable fields



163
164
165
166
167
168
# File 'lib/advanced_billing/models/metered_component.rb', line 163

def self.nullables
  %w[
    interval_unit
    unspsc_code
  ]
end

.optionalsObject

An array for optional fields



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/advanced_billing/models/metered_component.rb', line 143

def self.optionals
  %w[
    description
    handle
    taxable
    prices
    price_points
    unit_price
    tax_code
    hide_date_range_on_invoice
    display_on_hosted_page
    allow_fractional_quantities
    public_signup_page_ids
    interval
    interval_unit
    unspsc_code
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/advanced_billing/models/metered_component.rb', line 283

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.name,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.unit_name,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.pricing_scheme,
                              ->(val) { PricingScheme.validate(val) })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['name'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['unit_name'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['pricing_scheme'],
                            ->(val) { PricingScheme.validate(val) })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/advanced_billing/models/metered_component.rb', line 321

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, unit_name: #{@unit_name.inspect}, description:"\
  " #{@description.inspect}, handle: #{@handle.inspect}, taxable: #{@taxable.inspect},"\
  " pricing_scheme: #{@pricing_scheme.inspect}, prices: #{@prices.inspect}, price_points:"\
  " #{@price_points.inspect}, unit_price: #{@unit_price.inspect}, tax_code:"\
  " #{@tax_code.inspect}, hide_date_range_on_invoice: #{@hide_date_range_on_invoice.inspect},"\
  " display_on_hosted_page: #{@display_on_hosted_page.inspect}, allow_fractional_quantities:"\
  " #{@allow_fractional_quantities.inspect}, public_signup_page_ids:"\
  " #{@public_signup_page_ids.inspect}, interval: #{@interval.inspect}, interval_unit:"\
  " #{@interval_unit.inspect}, unspsc_code: #{@unspsc_code.inspect}, additional_properties:"\
  " #{get_additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



308
309
310
311
312
313
314
315
316
317
318
# File 'lib/advanced_billing/models/metered_component.rb', line 308

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, unit_name: #{@unit_name}, description: #{@description},"\
  " handle: #{@handle}, taxable: #{@taxable}, pricing_scheme: #{@pricing_scheme}, prices:"\
  " #{@prices}, price_points: #{@price_points}, unit_price: #{@unit_price}, tax_code:"\
  " #{@tax_code}, hide_date_range_on_invoice: #{@hide_date_range_on_invoice},"\
  " display_on_hosted_page: #{@display_on_hosted_page}, allow_fractional_quantities:"\
  " #{@allow_fractional_quantities}, public_signup_page_ids: #{@public_signup_page_ids},"\
  " interval: #{@interval}, interval_unit: #{@interval_unit}, unspsc_code: #{@unspsc_code},"\
  " additional_properties: #{get_additional_properties}>"
end