Class: AdvancedBilling::PrepaidUsageComponent
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- AdvancedBilling::PrepaidUsageComponent
- Defined in:
- lib/advanced_billing/models/prepaid_usage_component.rb
Overview
PrepaidUsageComponent Model.
Instance Attribute Summary collapse
-
#allow_fractional_quantities ⇒ TrueClass | FalseClass
(only for prepaid usage components where rollover_prepaid_remainder is true) The number of
expiration_interval_units after which rollover amounts should expire. -
#description ⇒ String
A description for the component that will be displayed to the user on the hosted signup page.
-
#display_on_hosted_page ⇒ TrueClass | FalseClass
(only for prepaid usage components where rollover_prepaid_remainder is true) The number of
expiration_interval_units after which rollover amounts should expire. -
#downgrade_credit ⇒ CreditType
The type of credit to be created when upgrading/downgrading.
-
#expiration_interval ⇒ Float
(only for prepaid usage components where rollover_prepaid_remainder is true) The number of
expiration_interval_units after which rollover amounts should expire. -
#expiration_interval_unit ⇒ ExpirationIntervalUnit
(only for prepaid usage components where rollover_prepaid_remainder is true) The number of
expiration_interval_units after which rollover amounts should expire. -
#handle ⇒ String
A unique identifier for your use that can be used to retrieve this component in subsequent requests.
-
#hide_date_range_on_invoice ⇒ TrueClass | FalseClass
(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.
-
#name ⇒ String
A name for this component that is suitable for showing customers and displaying on billing statements, e.g., "Minutes".
-
#overage_pricing ⇒ OveragePricing
(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.
-
#price_points ⇒ Array[CreatePrepaidUsageComponentPricePoint]
The type of credit to be created when upgrading/downgrading.
-
#prices ⇒ Array[Price]
(Not required for ‘per_unit’ pricing schemes) One or more price brackets.
-
#pricing_scheme ⇒ PricingScheme
The identifier for the pricing scheme.
-
#public_signup_page_ids ⇒ Array[Integer]
(only for prepaid usage components where rollover_prepaid_remainder is true) The number of
expiration_interval_units after which rollover amounts should expire. -
#renew_prepaid_allocation ⇒ TrueClass | FalseClass
Boolean which controls whether or not the allocated quantity should be renewed at the beginning of each period.
-
#rollover_prepaid_remainder ⇒ TrueClass | FalseClass
Boolean which controls whether or not remaining units should be rolled over to the next period.
-
#tax_code ⇒ String
A string representing the tax code related to the component type.
-
#taxable ⇒ TrueClass | FalseClass
Boolean flag describing whether a component is taxable or not.
-
#unit_name ⇒ String
The name of the unit of measurement for the component.
-
#unit_price ⇒ Object
The amount the customer will be charged per unit when the pricing scheme is “per_unit”.
-
#unspsc_code ⇒ String
(Optional) Custom UNSPSC commodity code for Level 3/CEDP payment data.
-
#upgrade_charge ⇒ CreditType
The type of credit to be created when upgrading/downgrading.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(name:, unit_name:, pricing_scheme:, overage_pricing:, description: SKIP, handle: SKIP, taxable: SKIP, prices: SKIP, upgrade_charge: SKIP, downgrade_credit: SKIP, price_points: SKIP, unit_price: SKIP, tax_code: SKIP, hide_date_range_on_invoice: SKIP, rollover_prepaid_remainder: SKIP, renew_prepaid_allocation: SKIP, expiration_interval: SKIP, expiration_interval_unit: SKIP, display_on_hosted_page: SKIP, allow_fractional_quantities: SKIP, public_signup_page_ids: SKIP, unspsc_code: SKIP, additional_properties: {}) ⇒ PrepaidUsageComponent
constructor
A new instance of PrepaidUsageComponent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #get_additional_properties, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, unit_name:, pricing_scheme:, overage_pricing:, description: SKIP, handle: SKIP, taxable: SKIP, prices: SKIP, upgrade_charge: SKIP, downgrade_credit: SKIP, price_points: SKIP, unit_price: SKIP, tax_code: SKIP, hide_date_range_on_invoice: SKIP, rollover_prepaid_remainder: SKIP, renew_prepaid_allocation: SKIP, expiration_interval: SKIP, expiration_interval_unit: SKIP, display_on_hosted_page: SKIP, allow_fractional_quantities: SKIP, public_signup_page_ids: SKIP, unspsc_code: SKIP, additional_properties: {}) ⇒ PrepaidUsageComponent
Returns a new instance of PrepaidUsageComponent.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 203 def initialize(name:, unit_name:, pricing_scheme:, overage_pricing:, description: SKIP, handle: SKIP, taxable: SKIP, prices: SKIP, upgrade_charge: SKIP, downgrade_credit: SKIP, price_points: SKIP, unit_price: SKIP, tax_code: SKIP, hide_date_range_on_invoice: SKIP, rollover_prepaid_remainder: SKIP, renew_prepaid_allocation: SKIP, expiration_interval: SKIP, expiration_interval_unit: SKIP, display_on_hosted_page: SKIP, allow_fractional_quantities: SKIP, public_signup_page_ids: SKIP, unspsc_code: SKIP, additional_properties: {}) # Add additional model properties to the instance. additional_properties.each do |_name, _value| instance_variable_set("@#{_name}", _value) end @name = name @unit_name = unit_name @description = description unless description == SKIP @handle = handle unless handle == SKIP @taxable = taxable unless taxable == SKIP @pricing_scheme = pricing_scheme @prices = prices unless prices == SKIP @upgrade_charge = upgrade_charge unless upgrade_charge == SKIP @downgrade_credit = downgrade_credit unless downgrade_credit == SKIP @price_points = price_points unless price_points == SKIP @unit_price = unit_price unless unit_price == SKIP @tax_code = tax_code unless tax_code == SKIP unless hide_date_range_on_invoice == SKIP @hide_date_range_on_invoice = hide_date_range_on_invoice end @overage_pricing = overage_pricing unless rollover_prepaid_remainder == SKIP @rollover_prepaid_remainder = rollover_prepaid_remainder end @renew_prepaid_allocation = renew_prepaid_allocation unless renew_prepaid_allocation == SKIP @expiration_interval = expiration_interval unless expiration_interval == SKIP @expiration_interval_unit = expiration_interval_unit unless expiration_interval_unit == SKIP @display_on_hosted_page = display_on_hosted_page unless display_on_hosted_page == SKIP unless allow_fractional_quantities == SKIP @allow_fractional_quantities = allow_fractional_quantities end @public_signup_page_ids = public_signup_page_ids unless public_signup_page_ids == SKIP @unspsc_code = unspsc_code unless unspsc_code == SKIP end |
Instance Attribute Details
#allow_fractional_quantities ⇒ TrueClass | FalseClass
(only for prepaid usage components where rollover_prepaid_remainder is
true) The number of expiration_interval_units after which rollover
amounts should expire
127 128 129 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 127 def allow_fractional_quantities @allow_fractional_quantities end |
#description ⇒ String
A description for the component that will be displayed to the user on the hosted signup page.
27 28 29 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 27 def description @description end |
#display_on_hosted_page ⇒ TrueClass | FalseClass
(only for prepaid usage components where rollover_prepaid_remainder is
true) The number of expiration_interval_units after which rollover
amounts should expire
121 122 123 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 121 def display_on_hosted_page @display_on_hosted_page end |
#downgrade_credit ⇒ CreditType
The type of credit to be created when upgrading/downgrading. Defaults to the component and then site setting if one is not provided.
62 63 64 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 62 def downgrade_credit @downgrade_credit end |
#expiration_interval ⇒ Float
(only for prepaid usage components where rollover_prepaid_remainder is
true) The number of expiration_interval_units after which rollover
amounts should expire
109 110 111 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 109 def expiration_interval @expiration_interval end |
#expiration_interval_unit ⇒ ExpirationIntervalUnit
(only for prepaid usage components where rollover_prepaid_remainder is
true) The number of expiration_interval_units after which rollover
amounts should expire
115 116 117 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 115 def expiration_interval_unit @expiration_interval_unit end |
#handle ⇒ String
A unique identifier for your use that can be used to retrieve this component in subsequent requests. Must start with a letter or number and may only contain lowercase letters, numbers, or the characters '.', ':', '-', or '_'.
34 35 36 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 34 def handle @handle end |
#hide_date_range_on_invoice ⇒ TrueClass | FalseClass
(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.
87 88 89 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 87 def hide_date_range_on_invoice @hide_date_range_on_invoice end |
#name ⇒ String
A name for this component that is suitable for showing customers and displaying on billing statements, e.g., "Minutes".
15 16 17 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 15 def name @name end |
#overage_pricing ⇒ OveragePricing
(Only available on Relationship Invoicing sites) Boolean flag describing if the service date range should show for the component on generated invoices.
93 94 95 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 93 def overage_pricing @overage_pricing end |
#price_points ⇒ Array[CreatePrepaidUsageComponentPricePoint]
The type of credit to be created when upgrading/downgrading. Defaults to the component and then site setting if one is not provided.
67 68 69 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 67 def price_points @price_points end |
#prices ⇒ Array[Price]
(Not required for ‘per_unit’ pricing schemes) One or more price brackets. See [Price Bracket Rules](https://maxio.zendesk.com/hc/en-us/articles/24261149166733-Componen t-Pricing-Schemes#price-bracket-rules) for an overview of how price brackets work for different pricing schemes.
52 53 54 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 52 def prices @prices end |
#pricing_scheme ⇒ PricingScheme
The identifier for the pricing scheme. See Product Components for an overview of pricing schemes.
44 45 46 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 44 def pricing_scheme @pricing_scheme end |
#public_signup_page_ids ⇒ Array[Integer]
(only for prepaid usage components where rollover_prepaid_remainder is
true) The number of expiration_interval_units after which rollover
amounts should expire
133 134 135 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 133 def public_signup_page_ids @public_signup_page_ids end |
#renew_prepaid_allocation ⇒ TrueClass | FalseClass
Boolean which controls whether or not the allocated quantity should be renewed at the beginning of each period.
103 104 105 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 103 def renew_prepaid_allocation @renew_prepaid_allocation end |
#rollover_prepaid_remainder ⇒ TrueClass | FalseClass
Boolean which controls whether or not remaining units should be rolled over to the next period.
98 99 100 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 98 def rollover_prepaid_remainder @rollover_prepaid_remainder end |
#tax_code ⇒ String
A string representing the tax code related to the component type. This is especially important when using AvaTax to tax based on locale. This attribute has a max length of 25 characters.
81 82 83 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 81 def tax_code @tax_code end |
#taxable ⇒ TrueClass | FalseClass
Boolean flag describing whether a component is taxable or not.
38 39 40 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 38 def taxable @taxable end |
#unit_name ⇒ String
The name of the unit of measurement for the component. It should be singular since it will be automatically pluralized when necessary. e.g., “message”, which may then be shown as “5 messages” on a subscription’s component line-item
22 23 24 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 22 def unit_name @unit_name end |
#unit_price ⇒ Object
The amount the customer will be charged per unit when the pricing scheme is “per_unit”. For On/Off Components, this is the amount that the customer will be charged when they turn the component on for the subscription. The price can contain up to 8 decimal places. e.g., 1.00 or 0.0012 or 0.00000065
75 76 77 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 75 def unit_price @unit_price end |
#unspsc_code ⇒ String
(Optional) Custom UNSPSC commodity code for Level 3/CEDP payment data. When set, this value is sent as the commodity code on invoice line items for this component instead of the default derived from item_category.
139 140 141 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 139 def unspsc_code @unspsc_code end |
#upgrade_charge ⇒ CreditType
The type of credit to be created when upgrading/downgrading. Defaults to the component and then site setting if one is not provided.
57 58 59 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 57 def upgrade_charge @upgrade_charge end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 253 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil unit_name = hash.key?('unit_name') ? hash['unit_name'] : nil pricing_scheme = hash.key?('pricing_scheme') ? hash['pricing_scheme'] : nil overage_pricing = OveragePricing.from_hash(hash['overage_pricing']) if hash['overage_pricing'] description = hash.key?('description') ? hash['description'] : SKIP handle = hash.key?('handle') ? hash['handle'] : SKIP taxable = hash.key?('taxable') ? hash['taxable'] : SKIP # Parameter is an array, so we need to iterate through it prices = nil unless hash['prices'].nil? prices = [] hash['prices'].each do |structure| prices << (Price.from_hash(structure) if structure) end end prices = SKIP unless hash.key?('prices') upgrade_charge = hash.key?('upgrade_charge') ? hash['upgrade_charge'] : SKIP downgrade_credit = hash.key?('downgrade_credit') ? hash['downgrade_credit'] : SKIP # Parameter is an array, so we need to iterate through it price_points = nil unless hash['price_points'].nil? price_points = [] hash['price_points'].each do |structure| price_points << (CreatePrepaidUsageComponentPricePoint.from_hash(structure) if structure) end end price_points = SKIP unless hash.key?('price_points') unit_price = hash.key?('unit_price') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:PrepaidUsageComponentUnitPrice), hash['unit_price'] ) : SKIP tax_code = hash.key?('tax_code') ? hash['tax_code'] : SKIP hide_date_range_on_invoice = hash.key?('hide_date_range_on_invoice') ? hash['hide_date_range_on_invoice'] : SKIP rollover_prepaid_remainder = hash.key?('rollover_prepaid_remainder') ? hash['rollover_prepaid_remainder'] : SKIP renew_prepaid_allocation = hash.key?('renew_prepaid_allocation') ? hash['renew_prepaid_allocation'] : SKIP expiration_interval = hash.key?('expiration_interval') ? hash['expiration_interval'] : SKIP expiration_interval_unit = hash.key?('expiration_interval_unit') ? hash['expiration_interval_unit'] : SKIP display_on_hosted_page = hash.key?('display_on_hosted_page') ? hash['display_on_hosted_page'] : SKIP allow_fractional_quantities = hash.key?('allow_fractional_quantities') ? hash['allow_fractional_quantities'] : SKIP public_signup_page_ids = hash.key?('public_signup_page_ids') ? hash['public_signup_page_ids'] : SKIP unspsc_code = hash.key?('unspsc_code') ? hash['unspsc_code'] : SKIP # Clean out expected properties from Hash. additional_properties = hash.reject { |k, _| names.value?(k) } # Create object from extracted values. PrepaidUsageComponent.new(name: name, unit_name: unit_name, pricing_scheme: pricing_scheme, overage_pricing: overage_pricing, description: description, handle: handle, taxable: taxable, prices: prices, upgrade_charge: upgrade_charge, downgrade_credit: downgrade_credit, price_points: price_points, unit_price: unit_price, tax_code: tax_code, hide_date_range_on_invoice: hide_date_range_on_invoice, rollover_prepaid_remainder: rollover_prepaid_remainder, renew_prepaid_allocation: renew_prepaid_allocation, expiration_interval: expiration_interval, expiration_interval_unit: expiration_interval_unit, display_on_hosted_page: display_on_hosted_page, allow_fractional_quantities: allow_fractional_quantities, public_signup_page_ids: public_signup_page_ids, unspsc_code: unspsc_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 142 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['unit_name'] = 'unit_name' @_hash['description'] = 'description' @_hash['handle'] = 'handle' @_hash['taxable'] = 'taxable' @_hash['pricing_scheme'] = 'pricing_scheme' @_hash['prices'] = 'prices' @_hash['upgrade_charge'] = 'upgrade_charge' @_hash['downgrade_credit'] = 'downgrade_credit' @_hash['price_points'] = 'price_points' @_hash['unit_price'] = 'unit_price' @_hash['tax_code'] = 'tax_code' @_hash['hide_date_range_on_invoice'] = 'hide_date_range_on_invoice' @_hash['overage_pricing'] = 'overage_pricing' @_hash['rollover_prepaid_remainder'] = 'rollover_prepaid_remainder' @_hash['renew_prepaid_allocation'] = 'renew_prepaid_allocation' @_hash['expiration_interval'] = 'expiration_interval' @_hash['expiration_interval_unit'] = 'expiration_interval_unit' @_hash['display_on_hosted_page'] = 'display_on_hosted_page' @_hash['allow_fractional_quantities'] = 'allow_fractional_quantities' @_hash['public_signup_page_ids'] = 'public_signup_page_ids' @_hash['unspsc_code'] = 'unspsc_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
194 195 196 197 198 199 200 201 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 194 def self.nullables %w[ upgrade_charge downgrade_credit expiration_interval_unit unspsc_code ] end |
.optionals ⇒ Object
An array for optional fields
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 170 def self.optionals %w[ description handle taxable prices upgrade_charge downgrade_credit price_points unit_price tax_code hide_date_range_on_invoice rollover_prepaid_remainder renew_prepaid_allocation expiration_interval expiration_interval_unit display_on_hosted_page allow_fractional_quantities public_signup_page_ids unspsc_code ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 343 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.unit_name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.pricing_scheme, ->(val) { PricingScheme.validate(val) }) and APIHelper.valid_type?(value.overage_pricing, ->(val) { OveragePricing.validate(val) }, is_model_hash: true) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['unit_name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['pricing_scheme'], ->(val) { PricingScheme.validate(val) }) and APIHelper.valid_type?(value['overage_pricing'], ->(val) { OveragePricing.validate(val) }, is_model_hash: true) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 390 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, unit_name: #{@unit_name.inspect}, description:"\ " #{@description.inspect}, handle: #{@handle.inspect}, taxable: #{@taxable.inspect},"\ " pricing_scheme: #{@pricing_scheme.inspect}, prices: #{@prices.inspect}, upgrade_charge:"\ " #{@upgrade_charge.inspect}, downgrade_credit: #{@downgrade_credit.inspect}, price_points:"\ " #{@price_points.inspect}, unit_price: #{@unit_price.inspect}, tax_code:"\ " #{@tax_code.inspect}, hide_date_range_on_invoice: #{@hide_date_range_on_invoice.inspect},"\ " overage_pricing: #{@overage_pricing.inspect}, rollover_prepaid_remainder:"\ " #{@rollover_prepaid_remainder.inspect}, renew_prepaid_allocation:"\ " #{@renew_prepaid_allocation.inspect}, expiration_interval:"\ " #{@expiration_interval.inspect}, expiration_interval_unit:"\ " #{@expiration_interval_unit.inspect}, display_on_hosted_page:"\ " #{@display_on_hosted_page.inspect}, allow_fractional_quantities:"\ " #{@allow_fractional_quantities.inspect}, public_signup_page_ids:"\ " #{@public_signup_page_ids.inspect}, unspsc_code: #{@unspsc_code.inspect},"\ " additional_properties: #{get_additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/advanced_billing/models/prepaid_usage_component.rb', line 374 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, unit_name: #{@unit_name}, description: #{@description},"\ " handle: #{@handle}, taxable: #{@taxable}, pricing_scheme: #{@pricing_scheme}, prices:"\ " #{@prices}, upgrade_charge: #{@upgrade_charge}, downgrade_credit: #{@downgrade_credit},"\ " price_points: #{@price_points}, unit_price: #{@unit_price}, tax_code: #{@tax_code},"\ " hide_date_range_on_invoice: #{@hide_date_range_on_invoice}, overage_pricing:"\ " #{@overage_pricing}, rollover_prepaid_remainder: #{@rollover_prepaid_remainder},"\ " renew_prepaid_allocation: #{@renew_prepaid_allocation}, expiration_interval:"\ " #{@expiration_interval}, expiration_interval_unit: #{@expiration_interval_unit},"\ " display_on_hosted_page: #{@display_on_hosted_page}, allow_fractional_quantities:"\ " #{@allow_fractional_quantities}, public_signup_page_ids: #{@public_signup_page_ids},"\ " unspsc_code: #{@unspsc_code}, additional_properties: #{get_additional_properties}>" end |