Class: AdvancedBilling::ScheduledRenewalConfigurationsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/advanced_billing/models/scheduled_renewal_configurations_response.rb

Overview

ScheduledRenewalConfigurationsResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #get_additional_properties, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(scheduled_renewal_configurations: SKIP, additional_properties: {}) ⇒ ScheduledRenewalConfigurationsResponse

Returns a new instance of ScheduledRenewalConfigurationsResponse.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/advanced_billing/models/scheduled_renewal_configurations_response.rb', line 36

def initialize(scheduled_renewal_configurations: SKIP,
               additional_properties: {})
  # Add additional model properties to the instance.
  additional_properties.each do |_name, _value|
    instance_variable_set("@#{_name}", _value)
  end

  unless scheduled_renewal_configurations == SKIP
    @scheduled_renewal_configurations =
      scheduled_renewal_configurations
  end
end

Instance Attribute Details

#scheduled_renewal_configurationsArray[ScheduledRenewalConfiguration]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/advanced_billing/models/scheduled_renewal_configurations_response.rb', line 14

def scheduled_renewal_configurations
  @scheduled_renewal_configurations
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/advanced_billing/models/scheduled_renewal_configurations_response.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  scheduled_renewal_configurations = nil
  unless hash['scheduled_renewal_configurations'].nil?
    scheduled_renewal_configurations = []
    hash['scheduled_renewal_configurations'].each do |structure|
      scheduled_renewal_configurations << (ScheduledRenewalConfiguration.from_hash(structure) if structure)
    end
  end

  scheduled_renewal_configurations = SKIP unless hash.key?('scheduled_renewal_configurations')

  # Clean out expected properties from Hash.
  additional_properties = hash.reject { |k, _| names.value?(k) }

  # Create object from extracted values.
  ScheduledRenewalConfigurationsResponse.new(scheduled_renewal_configurations: scheduled_renewal_configurations,
                                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
22
# File 'lib/advanced_billing/models/scheduled_renewal_configurations_response.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['scheduled_renewal_configurations'] =
    'scheduled_renewal_configurations'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/advanced_billing/models/scheduled_renewal_configurations_response.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/advanced_billing/models/scheduled_renewal_configurations_response.rb', line 25

def self.optionals
  %w[
    scheduled_renewal_configurations
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
86
# File 'lib/advanced_billing/models/scheduled_renewal_configurations_response.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} scheduled_renewal_configurations:"\
  " #{@scheduled_renewal_configurations.inspect}, additional_properties:"\
  " #{get_additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/advanced_billing/models/scheduled_renewal_configurations_response.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} scheduled_renewal_configurations: #{@scheduled_renewal_configurations},"\
  " additional_properties: #{get_additional_properties}>"
end