Class: AdvancedBilling::SendEmail
- Defined in:
- lib/advanced_billing/models/send_email.rb
Overview
SendEmail Model.
Instance Attribute Summary collapse
-
#can_execute ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#url ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(can_execute:, url:, additional_properties: {}) ⇒ SendEmail
constructor
A new instance of SendEmail.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #get_additional_properties, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(can_execute:, url:, additional_properties: {}) ⇒ SendEmail
Returns a new instance of SendEmail.
38 39 40 41 42 43 44 45 46 |
# File 'lib/advanced_billing/models/send_email.rb', line 38 def initialize(can_execute:, url:, additional_properties: {}) # Add additional model properties to the instance. additional_properties.each do |_name, _value| instance_variable_set("@#{_name}", _value) end @can_execute = can_execute @url = url end |
Instance Attribute Details
#can_execute ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/advanced_billing/models/send_email.rb', line 14 def can_execute @can_execute end |
#url ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/advanced_billing/models/send_email.rb', line 18 def url @url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/advanced_billing/models/send_email.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. can_execute = hash.key?('can_execute') ? hash['can_execute'] : nil url = hash.key?('url') ? hash['url'] : nil # Clean out expected properties from Hash. additional_properties = hash.reject { |k, _| names.value?(k) } # Create object from extracted values. SendEmail.new(can_execute: can_execute, url: url, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/advanced_billing/models/send_email.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['can_execute'] = 'can_execute' @_hash['url'] = 'url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/advanced_billing/models/send_email.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/advanced_billing/models/send_email.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/advanced_billing/models/send_email.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} can_execute: #{@can_execute.inspect}, url: #{@url.inspect},"\ " additional_properties: #{get_additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/advanced_billing/models/send_email.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} can_execute: #{@can_execute}, url: #{@url}, additional_properties:"\ " #{get_additional_properties}>" end |