Class: AdvancedBilling::UpdateInvoiceRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/advanced_billing/models/update_invoice_request.rb

Overview

Request payload for updating a draft ad hoc invoice.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #get_additional_properties, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(invoice:, additional_properties: {}) ⇒ UpdateInvoiceRequest

Returns a new instance of UpdateInvoiceRequest.



34
35
36
37
38
39
40
41
# File 'lib/advanced_billing/models/update_invoice_request.rb', line 34

def initialize(invoice:, additional_properties: {})
  # Add additional model properties to the instance.
  additional_properties.each do |_name, _value|
    instance_variable_set("@#{_name}", _value)
  end

  @invoice = invoice
end

Instance Attribute Details

#invoiceUpdateInvoice

Attributes of a draft ad hoc invoice which can be updated. Only the submitted attributes are changed.

Returns:



15
16
17
# File 'lib/advanced_billing/models/update_invoice_request.rb', line 15

def invoice
  @invoice
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/advanced_billing/models/update_invoice_request.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  invoice = UpdateInvoice.from_hash(hash['invoice']) if hash['invoice']

  # Clean out expected properties from Hash.
  additional_properties = hash.reject { |k, _| names.value?(k) }

  # Create object from extracted values.
  UpdateInvoiceRequest.new(invoice: invoice,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/advanced_billing/models/update_invoice_request.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['invoice'] = 'invoice'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/advanced_billing/models/update_invoice_request.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/advanced_billing/models/update_invoice_request.rb', line 25

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



65
66
67
68
69
# File 'lib/advanced_billing/models/update_invoice_request.rb', line 65

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} invoice: #{@invoice.inspect}, additional_properties:"\
  " #{get_additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



59
60
61
62
# File 'lib/advanced_billing/models/update_invoice_request.rb', line 59

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} invoice: #{@invoice}, additional_properties: #{get_additional_properties}>"
end