Class: AdvancedBilling::CouponsController

Inherits:
BaseController show all
Defined in:
lib/advanced_billing/controllers/coupons_controller.rb

Overview

CouponsController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from AdvancedBilling::BaseController

Instance Method Details

#archive_coupon(product_family_id, coupon_id) ⇒ CouponResponse

Archives a coupon, making it unavailable for future use while remaining active on existing subscriptions. Archiving makes that Coupon unavailable for future use, but allows it to remain attached and functional on existing Subscriptions that are using it. The ‘archived_at` date and time will be assigned. Billing id of the product family to which the coupon belongs the coupon

Parameters:

  • product_family_id (Integer)

    Required parameter: The Advanced

  • coupon_id (Integer)

    Required parameter: The Advanced Billing id of

Returns:



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 222

def archive_coupon(product_family_id,
                   coupon_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/product_families/{product_family_id}/coupons/{coupon_id}.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(product_family_id, key: 'product_family_id')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(coupon_id, key: 'coupon_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponResponse.method(:from_hash)))
    .execute
end

#create_coupon(product_family_id, body: nil) ⇒ CouponResponse

Creates a coupon under the specified product family. You can create either a flat amount coupon by specifying amount_in_cents, or a percentage coupon by specifying percentage You can restrict a coupon to only apply to specific products / components by optionally passing in ‘restricted_products` and/or `restricted_components` objects in the format: `{ “<product_id/component_id>”: boolean_value }` Coupons can be administered in the Advanced Billing application or created via API. See [creating coupons](maxio.zendesk.com/hc/en-us/articles/24261212433165-Creati ng-Editing-Deleting-Coupons) for more information. See [Apply Coupons to Subscriptions](maxio.zendesk.com/hc/en-us/articles/24261259337101- Coupons-and-Subscriptions) for information on applying a coupon to a subscription in the Advanced Billing UI. Billing id of the product family to which the coupon belongs here

Parameters:

  • product_family_id (Integer)

    Required parameter: The Advanced

  • body (CouponRequest) (defaults to: nil)

    Optional parameter: TODO: type description

Returns:



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 29

def create_coupon(product_family_id,
                  body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/product_families/{product_family_id}/coupons.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(product_family_id, key: 'product_family_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponResponse.method(:from_hash))
                .local_error_template('422',
                                      'HTTP Response Not OK. Status code: {$statusCode}.'\
                                       ' Response: \'{$response.body}\'.',
                                      ErrorListResponseException))
    .execute
end

#create_coupon_subcodes(coupon_id, body: nil) ⇒ CouponSubcodesResponse

Creates subcodes for an existing coupon. ## Coupon Subcodes Intro Coupon Subcodes allow you to create a set of unique codes that allow you to expand the use of one coupon. For example: Master Coupon Code: + SPRING2020 Coupon Subcodes: + SPRING90210 + DP80302 + SPRINGBALTIMORE Coupon subcodes can be administered in the Admin Interface or via the API. When creating a coupon subcode, you must specify a coupon to attach it to using the coupon_id. Valid coupon subcodes are all capital letters, contain only letters and numbers, and do not have any spaces. Lowercase letters will be capitalized before the subcode is created. ## Coupon Subcodes Documentation Full documentation on how to create coupon subcodes in the Advanced Billing UI can be located [here](maxio.zendesk.com/hc/en-us/articles/24261208729229-Coupon-C odes). Additionally, for documentation on how to apply a coupon to a Subscription within the Advanced Billing UI, see our documentation [here](maxio.zendesk.com/hc/en-us/articles/24261259337101-Coupons- and-Subscriptions). ## Create Coupon Subcode This request allows you to create specific subcodes underneath an existing coupon code. Note: If you are using any of the allowed special characters (“%”, “@”, “+”, “-”, “_”, and “.”), you must encode them for use in the URL.

% to %25
@ to %40
+ to %2B
- to %2D
_ to %5F
. to %2E

So, if the coupon subcode is ‘20%OFF`, the URL to delete this coupon subcode would be: `https://<subdomain>.chargify.com/coupons/567/codes/20%25OFF.<format>` the coupon here

Parameters:

  • coupon_id (Integer)

    Required parameter: The Advanced Billing id of

  • body (CouponSubcodes) (defaults to: nil)

    Optional parameter: TODO: type description

Returns:



437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 437

def create_coupon_subcodes(coupon_id,
                           body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/coupons/{coupon_id}/codes.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(coupon_id, key: 'coupon_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponSubcodesResponse.method(:from_hash)))
    .execute
end

#create_or_update_coupon_currency_prices(coupon_id, body: nil) ⇒ CouponCurrencyResponse

Creates and/or updates currency prices for an existing coupon. Multiple prices can be created or updated in a single request but each of the currencies must be defined on the site level already and the coupon must be an amount-based coupon, not percentage. Currency pricing for coupons must mirror the setup of the primary coupon pricing - if the primary coupon is percentage based, you will not be able to define pricing in non-primary currencies. the coupon description here

Parameters:

  • coupon_id (Integer)

    Required parameter: The Advanced Billing id of

  • body (CouponCurrencyRequest) (defaults to: nil)

    Optional parameter: TODO: type

Returns:



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 369

def create_or_update_coupon_currency_prices(coupon_id,
                                            body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/coupons/{coupon_id}/currency_prices.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(coupon_id, key: 'coupon_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponCurrencyResponse.method(:from_hash))
                .local_error_template('422',
                                      'HTTP Response Not OK. Status code: {$statusCode}.'\
                                       ' Response: \'{$response.body}\'.',
                                      ErrorStringMapResponseException))
    .execute
end

#delete_coupon_subcode(coupon_id, subcode) ⇒ void

This method returns an undefined value.

Deletes a specific subcode from a coupon. ## Example Given a coupon with an ID of 567, and a coupon subcode of 20OFF, the URL to ‘DELETE` this coupon subcode would be: “` subdomain.chargify.com/coupons/567/codes/20OFF.<format> “` Note: If you are using any of the allowed special characters (“%”, “@”, “+”, “-”, “_”, and “.”), you must encode them for use in the URL. | Special character | Encoding | |——————-|———-| | % | %25 | | @ | %40 | | + | %2B | | – | %2D | | _ | %5F | | . | %2E | ## Percent Encoding Example Or if the coupon subcode is 20%OFF, the URL to delete this coupon subcode would be: @https://<subdomain>.chargify.com/coupons/567/codes/20%25OFF.<format> the coupon to which the subcode belongs

Parameters:

  • coupon_id (Integer)

    Required parameter: The Advanced Billing id of

  • subcode (String)

    Required parameter: The subcode of the coupon



549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 549

def delete_coupon_subcode(coupon_id,
                          subcode)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/coupons/{coupon_id}/codes/{subcode}.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(coupon_id, key: 'coupon_id')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(subcode, key: 'subcode')
                                .is_required(true)
                                .should_encode(true))
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .is_response_void(true)
                .local_error_template('404',
                                      'Not Found:\'{$response.body}\'',
                                      APIException))
    .execute
end

#find_coupon(product_family_id: nil, code: nil, currency_prices: nil) ⇒ CouponResponse

Searches for a coupon by code, returning a 404 if no coupon is found. By passing a code parameter, the find will attempt to locate a coupon that matches that code. If you have more than one product family and if the coupon you are trying to find does not belong to the default product family in your site, then you will need to specify (either in the url or as a query string param) the product family id. Billing id of the product family to which the coupon belongs fetching coupons, if you have defined multiple currencies at the site level, you can optionally pass the ‘?currency_prices=true` query param to include an array of currency price data in the response.

Parameters:

  • product_family_id (Integer) (defaults to: nil)

    Optional parameter: The Advanced

  • code (String) (defaults to: nil)

    Optional parameter: The code of the coupon

  • currency_prices (TrueClass | FalseClass) (defaults to: nil)

    Optional parameter: When

Returns:



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 112

def find_coupon(product_family_id: nil,
                code: nil,
                currency_prices: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/coupons/find.json',
                                 Server::PRODUCTION)
               .query_param(new_parameter(product_family_id, key: 'product_family_id'))
               .query_param(new_parameter(code, key: 'code'))
               .query_param(new_parameter(currency_prices, key: 'currency_prices'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponResponse.method(:from_hash)))
    .execute
end

#list_coupon_subcodes(options = {}) ⇒ CouponSubcodes

Lists the subcodes attached to a coupon. the coupon pages. By default, the first page of results is displayed. The page parameter specifies a page number of results to fetch. You can start navigating through the pages to consume the results. You do this by passing in a page parameter. Retrieve the next page by adding ?page=2 to the query string. If there are no results to return, then an empty result set will be returned. Use in query ‘page=1`. many records to fetch in each request. Default value is 20. The maximum allowed values is 200; any per_page value over 200 will be changed to 200. Use in query `per_page=200`.

Parameters:

  • coupon_id (Integer)

    Required parameter: The Advanced Billing id of

  • page (Integer)

    Optional parameter: Result records are organized in

  • per_page (Integer)

    Optional parameter: This parameter indicates how

Returns:



472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 472

def list_coupon_subcodes(options = {})
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/coupons/{coupon_id}/codes.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(options['coupon_id'], key: 'coupon_id')
                                .is_required(true)
                                .should_encode(true))
               .query_param(new_parameter(options['page'], key: 'page'))
               .query_param(new_parameter(options['per_page'], key: 'per_page'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponSubcodes.method(:from_hash)))
    .execute
end

#list_coupons(options = {}) ⇒ Array[CouponResponse]

Lists coupons for a site. pages. By default, the first page of results is displayed. The page parameter specifies a page number of results to fetch. You can start navigating through the pages to consume the results. You do this by passing in a page parameter. Retrieve the next page by adding ?page=2 to the query string. If there are no results to return, then an empty result set will be returned. Use in query ‘page=1`. many records to fetch in each request. Default value is 30. The maximum allowed values is 200; any per_page value over 200 will be changed to 200. Use in query `per_page=200`. List Coupons operations fetching coupons, if you have defined multiple currencies at the site level, you can optionally pass the `?currency_prices=true` query param to include an array of currency price data in the response. Use in query `currency_prices=true`.

Parameters:

  • page (Integer)

    Optional parameter: Result records are organized in

  • per_page (Integer)

    Optional parameter: This parameter indicates how

  • filter (ListCouponsFilter)

    Optional parameter: Filter to use for

  • currency_prices (TrueClass | FalseClass)

    Optional parameter: When

Returns:



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 262

def list_coupons(options = {})
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/coupons.json',
                                 Server::PRODUCTION)
               .query_param(new_parameter(options['page'], key: 'page'))
               .query_param(new_parameter(options['per_page'], key: 'per_page'))
               .query_param(new_parameter(options['filter'], key: 'filter'))
               .query_param(new_parameter(options['currency_prices'], key: 'currency_prices'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('BasicAuth'))
               .array_serialization_format(ArraySerializationFormat::CSV))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponResponse.method(:from_hash))
                .is_response_array(true))
    .execute
end

#list_coupons_for_product_family(options = {}) ⇒ Array[CouponResponse]

Lists coupons for a specific product family in a site. Billing id of the product family to which the coupon belongs pages. By default, the first page of results is displayed. The page parameter specifies a page number of results to fetch. You can start navigating through the pages to consume the results. You do this by passing in a page parameter. Retrieve the next page by adding ?page=2 to the query string. If there are no results to return, then an empty result set will be returned. Use in query ‘page=1`. many records to fetch in each request. Default value is 30. The maximum allowed values is 200; any per_page value over 200 will be changed to 200. Use in query `per_page=200`. List Coupons operations fetching coupons, if you have defined multiple currencies at the site level, you can optionally pass the `?currency_prices=true` query param to include an array of currency price data in the response. Use in query `currency_prices=true`.

Parameters:

  • product_family_id (Integer)

    Required parameter: The Advanced

  • page (Integer)

    Optional parameter: Result records are organized in

  • per_page (Integer)

    Optional parameter: This parameter indicates how

  • filter (ListCouponsFilter)

    Optional parameter: Filter to use for

  • currency_prices (TrueClass | FalseClass)

    Optional parameter: When

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 75

def list_coupons_for_product_family(options = {})
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/product_families/{product_family_id}/coupons.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(options['product_family_id'], key: 'product_family_id')
                                .is_required(true)
                                .should_encode(true))
               .query_param(new_parameter(options['page'], key: 'page'))
               .query_param(new_parameter(options['per_page'], key: 'per_page'))
               .query_param(new_parameter(options['filter'], key: 'filter'))
               .query_param(new_parameter(options['currency_prices'], key: 'currency_prices'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('BasicAuth'))
               .array_serialization_format(ArraySerializationFormat::CSV))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponResponse.method(:from_hash))
                .is_response_array(true))
    .execute
end

#read_coupon(product_family_id, coupon_id, currency_prices: nil) ⇒ CouponResponse

Returns a coupon by its Advanced Billing-assigned ID. You must identify the Coupon in this call by the ID parameter that Advanced Billing assigns. If instead you would like to find a Coupon using a Coupon code, see the Coupon Find method. When fetching a coupon, if you have defined multiple currencies at the site level, you can optionally pass the ‘?currency_prices=true` query param to include an array of currency price data in the response. If the coupon is set to `use_site_exchange_rate: true`, it will return pricing based on the current exchange rate. If the flag is set to false, it will return all of the defined prices for each currency. Billing id of the product family to which the coupon belongs the coupon fetching coupons, if you have defined multiple currencies at the site level, you can optionally pass the `?currency_prices=true` query param to include an array of currency price data in the response.

Parameters:

  • product_family_id (Integer)

    Required parameter: The Advanced

  • coupon_id (Integer)

    Required parameter: The Advanced Billing id of

  • currency_prices (TrueClass | FalseClass) (defaults to: nil)

    Optional parameter: When

Returns:



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 149

def read_coupon(product_family_id,
                coupon_id,
                currency_prices: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/product_families/{product_family_id}/coupons/{coupon_id}.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(product_family_id, key: 'product_family_id')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(coupon_id, key: 'coupon_id')
                                .is_required(true)
                                .should_encode(true))
               .query_param(new_parameter(currency_prices, key: 'currency_prices'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponResponse.method(:from_hash)))
    .execute
end

#read_coupon_usage(product_family_id, coupon_id) ⇒ Array[CouponUsage]

Lists coupon usage details, one entry per product. Billing id of the product family to which the coupon belongs. the coupon.

Parameters:

  • product_family_id (Integer)

    Required parameter: The Advanced

  • coupon_id (Integer)

    Required parameter: The Advanced Billing id of

Returns:



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 287

def read_coupon_usage(product_family_id,
                      coupon_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/product_families/{product_family_id}/coupons/{coupon_id}/usage.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(product_family_id, key: 'product_family_id')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(coupon_id, key: 'coupon_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponUsage.method(:from_hash))
                .is_response_array(true))
    .execute
end

#update_coupon(product_family_id, coupon_id, body: nil) ⇒ CouponResponse

Updates a coupon. You can restrict a coupon to only apply to specific products / components by optionally passing in hashes of ‘restricted_products` and/or `restricted_components` in the format: `{ “<product/component_id>”: boolean_value }` Billing id of the product family to which the coupon belongs the coupon here

Parameters:

  • product_family_id (Integer)

    Required parameter: The Advanced

  • coupon_id (Integer)

    Required parameter: The Advanced Billing id of

  • body (CouponRequest) (defaults to: nil)

    Optional parameter: TODO: type description

Returns:



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 183

def update_coupon(product_family_id,
                  coupon_id,
                  body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/product_families/{product_family_id}/coupons/{coupon_id}.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(product_family_id, key: 'product_family_id')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(coupon_id, key: 'coupon_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponResponse.method(:from_hash))
                .local_error_template('422',
                                      'HTTP Response Not OK. Status code: {$statusCode}.'\
                                       ' Response: \'{$response.body}\'.',
                                      ErrorListResponseException))
    .execute
end

#update_coupon_subcodes(coupon_id, body: nil) ⇒ CouponSubcodesResponse

Updates the subcodes for a coupon, replacing all existing subcodes with the new list. Send an array of new coupon subcodes. Note: All current subcodes for that Coupon will be deleted first, and replaced with the list of subcodes sent to this endpoint. The response will contain: + The created subcodes, + Subcodes that were not created because they already exist, + Any subcodes not created because they are invalid. the coupon here

Parameters:

  • coupon_id (Integer)

    Required parameter: The Advanced Billing id of

  • body (CouponSubcodes) (defaults to: nil)

    Optional parameter: TODO: type description

Returns:



504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 504

def update_coupon_subcodes(coupon_id,
                           body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/coupons/{coupon_id}/codes.json',
                                 Server::PRODUCTION)
               .template_param(new_parameter(coupon_id, key: 'coupon_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponSubcodesResponse.method(:from_hash)))
    .execute
end

#validate_coupon(code, product_family_id: nil) ⇒ CouponResponse

Verifies whether a specific coupon code is valid. This method is useful for validating coupon codes that are entered by a customer. If the coupon is found and is valid, the coupon will be returned with a 200 status code. If the coupon is invalid, the status code will be 404 and the response will say why it is invalid. If the coupon is valid, the status code will be 200 and the coupon will be returned. The following reasons for invalidity are supported: + Coupon not found + Coupon is invalid + Coupon expired If you have more than one product family and if the coupon you are validating does not belong to the first product family in your site, then you will need to specify the product family, either in the url or as a query string param. This can be done by supplying the id or the handle in the ‘handle:my-family` format. Eg. “` https://<subdomain>.chargify.com/product_families/handle:<product_family_h andle>/coupons/validate.<format>?code=<coupon_code> “` Or: “` https://<subdomain>.chargify.com/coupons/validate.<format>?code=<coupon_co de>&product_family_id=<id> “` Billing id of the product family to which the coupon belongs

Parameters:

  • code (String)

    Required parameter: The code of the coupon

  • product_family_id (Integer) (defaults to: nil)

    Optional parameter: The Advanced

Returns:



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/advanced_billing/controllers/coupons_controller.rb', line 337

def validate_coupon(code,
                    product_family_id: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/coupons/validate.json',
                                 Server::PRODUCTION)
               .query_param(new_parameter(code, key: 'code')
                             .is_required(true))
               .query_param(new_parameter(product_family_id, key: 'product_family_id'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('BasicAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CouponResponse.method(:from_hash))
                .local_error_template('404',
                                      'Not Found: \'{$response.body}\'',
                                      SingleStringErrorResponseException))
    .execute
end